Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/server.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJoas Schilling <coding@schilljs.com>2020-11-16 21:17:21 +0300
committerJoas Schilling <coding@schilljs.com>2020-11-16 21:46:24 +0300
commita8cb8e21c136dac2992f125f1270468b807dd4b2 (patch)
tree2772ac378d98172ae853317ecc9f2d3d3e64f10f /lib/public/DB
parent426dc68b456f4ea5c5bfbe9f07053e17924ea31a (diff)
Add types to function builder
Signed-off-by: Joas Schilling <coding@schilljs.com>
Diffstat (limited to 'lib/public/DB')
-rw-r--r--lib/public/DB/QueryBuilder/IFunctionBuilder.php54
1 files changed, 27 insertions, 27 deletions
diff --git a/lib/public/DB/QueryBuilder/IFunctionBuilder.php b/lib/public/DB/QueryBuilder/IFunctionBuilder.php
index aa11e42d622..569bc7485d4 100644
--- a/lib/public/DB/QueryBuilder/IFunctionBuilder.php
+++ b/lib/public/DB/QueryBuilder/IFunctionBuilder.php
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
/**
* Calculates the MD5 hash of a given input
*
- * @param mixed $input The input to be hashed
+ * @param string|ILiteral|IParameter|IQueryFunction $input The input to be hashed
*
* @return IQueryFunction
* @since 12.0.0
*/
- public function md5($input);
+ public function md5($input): IQueryFunction;
/**
* Combines two input strings
*
* @param mixed $x The first input string
* @param mixed $y The seccond input string
*
* @return IQueryFunction
* @since 12.0.0
*/
- public function concat($x, $y);
+ public function concat($x, $y): IQueryFunction;
/**
* Takes a substring from the input string
*
* @param mixed $input The input string
* @param mixed $start The start of the substring, note that counting starts at 1
* @param mixed $length The length of the substring
*
* @return IQueryFunction
* @since 12.0.0
*/
- public function substring($input, $start, $length = null);
+ public function substring($input, $start, $length = null): IQueryFunction;
/**
* Takes the sum of all rows in a column
*
* @param mixed $field the column to sum
*
* @return IQueryFunction
* @since 12.0.0
*/
- public function sum($field);
+ public function sum($field): IQueryFunction;
/**
* Transforms a string field or value to lower case
*
- * @param mixed $field
+ * @param string|ILiteral|IParameter|IQueryFunction $field
* @return IQueryFunction
* @since 14.0.0
*/
- public function lower($field);
+ public function lower($field): IQueryFunction;
/**
* @param mixed $x The first input field or number
* @param mixed $y The second input field or number
* @return IQueryFunction
* @since 14.0.0
*/
- public function add($x, $y);
+ public function add($x, $y): IQueryFunction;
/**
* @param mixed $x The first input field or number
* @param mixed $y The second input field or number
* @return IQueryFunction
* @since 14.0.0
*/
- public function subtract($x, $y);
+ public function subtract($x, $y): IQueryFunction;
/**
* @param mixed $count The input to be counted
* @param string $alias Alias for the counter
*
* @return IQueryFunction
* @since 14.0.0
*/
- public function count($count = '', $alias = '');
+ public function count($count = '', $alias = ''): IQueryFunction;
/**
* Takes the maximum of all rows in a column
*
* If you want to get the maximum value of multiple columns in the same row, use `greatest` instead
*
* @param mixed $field the column to maximum
*
* @return IQueryFunction
* @since 18.0.0
*/
- public function max($field);
+ public function max($field): IQueryFunction;
/**
* Takes the minimum of all rows in a column
*
* If you want to get the minimum value of multiple columns in the same row, use `least` instead
*
* @param mixed $field the column to minimum
*
* @return IQueryFunction
* @since 18.0.0
*/
- public function min($field);
+ public function min($field): IQueryFunction;
/**
* Takes the maximum of multiple values
@@ -142,7 +142,7 @@ interface IFunctionBuilder {
* @return IQueryFunction
* @since 18.0.0
*/
- public function greatest($x, $y);
+ public function greatest($x, $y): IQueryFunction;
/**
* Takes the minimum of multiple values
@@ -154,5 +154,5 @@ interface IFunctionBuilder {
* @return IQueryFunction
* @since 18.0.0
*/
- public function least($x, $y);
+ public function least($x, $y): IQueryFunction;
}
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
* Combines two input strings
*
- * @param mixed $x The first input string
- * @param mixed $y The seccond input string
+ * @param string|ILiteral|IParameter|IQueryFunction $x The first input string
+ * @param string|ILiteral|IParameter|IQueryFunction $y The seccond input string
*
* @return IQueryFunction
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
* Takes a substring from the input string
*
- * @param mixed $input The input string
- * @param mixed $start The start of the substring, note that counting starts at 1
- * @param mixed $length The length of the substring
+ * @param string|ILiteral|IParameter|IQueryFunction $input The input string
+ * @param string|ILiteral|IParameter|IQueryFunction $start The start of the substring, note that counting starts at 1
+ * @param null|ILiteral|IParameter|IQueryFunction $length The length of the substring
*
* @return IQueryFunction
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
* Takes the sum of all rows in a column
*
- * @param mixed $field the column to sum
+ * @param string|ILiteral|IParameter|IQueryFunction $field the column to sum
*
* @return IQueryFunction
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
/**
- * @param mixed $x The first input field or number
- * @param mixed $y The second input field or number
+ * @param string|ILiteral|IParameter|IQueryFunction $x The first input field or number
+ * @param string|ILiteral|IParameter|IQueryFunction $y The second input field or number
* @return IQueryFunction
* @since 14.0.0
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
/**
- * @param mixed $x The first input field or number
- * @param mixed $y The second input field or number
+ * @param string|ILiteral|IParameter|IQueryFunction $x The first input field or number
+ * @param string|ILiteral|IParameter|IQueryFunction $y The second input field or number
* @return IQueryFunction
* @since 14.0.0
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
/**
- * @param mixed $count The input to be counted
+ * @param string|ILiteral|IParameter|IQueryFunction $count The input to be counted
* @param string $alias Alias for the counter
*
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
* If you want to get the maximum value of multiple columns in the same row, use `greatest` instead
*
- * @param mixed $field the column to maximum
+ * @param string|ILiteral|IParameter|IQueryFunction $field the column to maximum
*
* @return IQueryFunction
@@ -34,103 +34,103 @@ interface IFunctionBuilder {
* If you want to get the minimum value of multiple columns in the same row, use `least` instead
*
- * @param mixed $field the column to minimum
+ * @param string|ILiteral|IParameter|IQueryFunction $field the column to minimum
*
* @return IQueryFunction